@@ -3,6 +3,9 @@ database_local_new <- function(
   path = NULL,
   key = NULL,
   header = NULL,
+  logical_columns = NULL,
+  integer_columns = NULL,
+  numeric_columns = NULL,
   list_columns = NULL,
   list_column_modes = NULL,
   resources = NULL,
@@ -13,6 +16,9 @@ database_local_new <- function(
     path = path,
     key = key,
     header = header,
+    logical_columns = logical_columns,
+    integer_columns = integer_columns,
+    numeric_columns = numeric_columns,
     list_columns = list_columns,
     list_column_modes = list_column_modes,
     resources = resources,
